#!/bin/bash

# Use environment variables or default values
RETHINKDB_HOST=${RETHINKDB_HOST:-localhost}
RETHINKDB_PORT=${RETHINKDB_PORT:-28015}
RETHINKDB_DATABASE=${RETHINKDB_DATABASE:-sharepulse}
SHAREPULSE_FILEPASSWORD_LENGTH=${SHAREPULSE_FILEPASSWORD_LENGTH:-6}
SHAREPULSE_FILEID_LENGTH=${SHAREPULSE_FILEID_LENGTH:-6}
SHAREPULSE_TEMP_FILESTORE_PATH=${SHAREPULSE_TEMP_FILESTORE_PATH:-/temp-filestore}
SHAREPULSE_AUTO_RESET_ON_STARTUP=${SHAREPULSE_AUTO_RESET_ON_STARTUP:-true}
MAX_FILE_SIZE=${MAX_FILE_SIZE:-1GB}
MAX_REQUEST_SIZE=${MAX_REQUEST_SIZE:-1GB}

# Inject environment variables into application.properties or use SPRING_APPLICATION_JSON
export SPRING_APPLICATION_JSON=$(cat << EOF
{
  "rethinkdb.host": "$RETHINKDB_HOST",
  "rethinkdb.port": $RETHINKDB_PORT,
  "rethinkdb.database": "$RETHINKDB_DATABASE",
  "sharepulse.filepassword.length": $SHAREPULSE_FILEPASSWORD_LENGTH,
  "sharepulse.fileid.length": $SHAREPULSE_FILEID_LENGTH,
  "sharepulse.temp-filestore-path": "$SHAREPULSE_TEMP_FILESTORE_PATH",
  "sharepulse.auto-reset-on-startup": $SHAREPULSE_AUTO_RESET_ON_STARTUP,
  "spring.servlet.multipart.max-file-size": "$MAX_FILE_SIZE",
  "spring.servlet.multipart.max-request-size": "$MAX_REQUEST_SIZE"
}
EOF
)

# Execute the jar file
exec java -jar sharepulse.jar