import {Component, ElementRef, ViewChild} from '@angular/core';
import {RouterLink} from "@angular/router";
import {NgClass} from "@angular/common";
import {FormsModule} from "@angular/forms";
import {LegalService} from "../../service/legalService";

@Component({
  selector: 'app-navbar',
  standalone: true,
    imports: [
        RouterLink,
        NgClass,
        FormsModule
    ],
  templateUrl: './navbar.component.html',
  styleUrl: './navbar.component.scss'
})
export class NavbarComponent {

  @ViewChild('privacy_policy_modal') privacy_policy_modal: ElementRef<HTMLDialogElement> | undefined;
  @ViewChild('terms_of_use_modal') terms_of_use_modal: ElementRef<HTMLDialogElement> | undefined;

  isMenuOpen = false;

  constructor(private legalService: LegalService) {
    this.legalService.openModal$.subscribe((modalId) => {
      if (modalId === 'privacyPolicy') {
        this.openPrivacyPolicy();
      } else if (modalId === 'termsOfUse') {
        this.openTermsOfUse();
      }
    });
  }

  toggleMenu(): void {
    this.isMenuOpen = !this.isMenuOpen;
  }

  openPrivacyPolicy() {
    this.privacy_policy_modal?.nativeElement.showModal();
  }

  openTermsOfUse() {
    this.terms_of_use_modal?.nativeElement.showModal();
  }
}
