package de.w665.sharepulse.db.repo;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.reflect.TypeToken;
import com.rethinkdb.RethinkDB;
import com.rethinkdb.net.Connection;
import de.w665.sharepulse.db.RethinkDBConnector;
import de.w665.sharepulse.model.FileUpload;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import java.lang.reflect.Type;
import java.util.List;
import java.util.Map;

@Repository
public class ExpiredFileUploadRepository {

    private final RethinkDB r;
    private final Connection connection;
    private final Gson gson;

    @Autowired
    public ExpiredFileUploadRepository(RethinkDBConnector connector) {
        this.r = connector.getR();
        this.connection = connector.getConnection();
        this.gson = new GsonBuilder().create();
    }

    public void insertExpiredFileUpload(FileUpload fileUpload) {
        String json = gson.toJson(fileUpload);

        Type type = new TypeToken<Map<String, Object>>(){}.getType();
        Map<String, Object> map = gson.fromJson(json, type);

        long uploadDateTimestamp = fileUpload.getUploadDate().getTime() / 1000;
        map.put("uploadDate", uploadDateTimestamp);

        r.db("sharepulse").table("expired_file_uploads").insert(map).run(connection);
    }

    public void deleteExpiredFileUpload(FileUpload fileUpload) {
        r.db("sharepulse").table("expired_file_uploads")
                .filter(r.hashMap("fileId", fileUpload.getFileId()))
                .delete()
                .run(connection);
    }

    public List<FileUpload> findAll() {
        return r.db("sharepulse").table("expired_file_uploads")
                .run(connection, FileUpload.class)
                .toList();
    }
}
