package de.w665.sharepulse.db.repo;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.rethinkdb.RethinkDB;
import com.rethinkdb.net.Connection;
import com.rethinkdb.net.Result;
import de.w665.sharepulse.db.RethinkDBConfig;
import de.w665.sharepulse.db.RethinkDBConnector;
import de.w665.sharepulse.model.FileUpload;
import de.w665.sharepulse.model.User;
import de.w665.sharepulse.model.UserLogin;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;


import java.lang.reflect.Type;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Repository
public class UserLoginRepository {
    private final RethinkDB r;
    private final Connection connection;
    private final RethinkDBConfig config;
    private final String TABLE_NAME = "user_logins";

    private final Gson gson = new Gson();
    private final ObjectMapper mapper = new ObjectMapper();


    @Autowired
    public UserLoginRepository(RethinkDBConnector connector, RethinkDBConfig config) {
        this.r = connector.getR();
        this.connection = connector.getConnection();
        this.config = config;
    }

    public void insertUserLogin(UserLogin userLogin) {
        String uuid = r.uuid().run(connection, String.class).first();
        userLogin.setId(uuid);
        r.db(config.getDatabase()).table(TABLE_NAME).insert(userLogin).run(connection);
    }

    public List<UserLogin> getRecentUserLoginsForUser(String userId, int limit) throws JsonProcessingException {
         Result<Object> rawResult = r.db("sharepulse").table(TABLE_NAME)
                 .filter(r.hashMap("userId", userId))
                 .orderBy(r.desc("sort"))
                 .limit(limit)
                 .run(connection);

        String jsonString = mapper.writeValueAsString(rawResult.single());
        Type listType = new TypeToken<List<UserLogin>>() {}.getType();
        return gson.fromJson(jsonString, listType);
    }

    private UserLogin convertToUserLogin(Object obj) {
        ObjectMapper mapper = new ObjectMapper();
        return mapper.convertValue(obj, UserLogin.class);
    }

    /*public List<UserLogin> getRecentUserLoginsForUser(String userId, int limit) {
        Result<Object> results =  r.db(config.getDatabase()).table(TABLE_NAME)
                .filter(r.hashMap("userId", userId))
                .orderBy(r.desc("loginTime"))
                .limit(limit)
                .run(connection);
        List<Object> objectList = results.toList();
        List<Object> obj = (List) objectList.get(0);
        System.out.println(obj.getFirst());
        UserLogin userLogin = (UserLogin) obj.getFirst();
        System.out.println(userLogin.toString());
        return null;
    }*/
}
