package de.w665.sharepulse.db.repo;

import com.rethinkdb.RethinkDB;
import com.rethinkdb.net.Connection;
import de.w665.sharepulse.db.RethinkDBConfig;
import de.w665.sharepulse.db.RethinkDBConnector;
import de.w665.sharepulse.model.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import java.util.*;

@Repository
public class UserRepository {
    private final RethinkDB r;
    private final Connection connection;
    private final RethinkDBConfig config;
    @Autowired
    public UserRepository(RethinkDBConnector connector, RethinkDBConfig config) {
        this.r = connector.getR();
        this.connection = connector.getConnection();
        this.config = config;
    }

    public Optional<User> retrieveUserByUsername(String username) {
        try {
            User user = r.db(config.getDatabase()).table("users")
                    .filter(r.hashMap("username", username))
                    .run(connection, User.class)
                    .next();
            return Optional.ofNullable(user);
        } catch (NoSuchElementException e) {
            return Optional.empty();
        }
    }

    public void updateLastLoginForUser(String username, Date lastLogin) {
        r.db(config.getDatabase()).table("users")
                .filter(r.hashMap("username", username))
                .update(r.hashMap("lastLogin", lastLogin.getTime()))
                .run(connection);
    }

    public void updateUser(User user) {
        r.db(config.getDatabase()).table("users")
                .filter(r.hashMap("username", user.getUsername()))
                .update(user)
                .run(connection);
    }

    // If username is changed, this method must be used. Else the user will not be found
    public void updateUser(User user, String originalUsername) {
        // TODO: Refactor this to use the userID instead of the username (remove this and use method above)
        r.db(config.getDatabase()).table("users")
                .filter(r.hashMap("username", originalUsername))
                .update(user)
                .run(connection);
    }

    public void insertUser(User user) {
        String optionalUuid = r.uuid().run(connection, String.class).first();
        user.setId(optionalUuid);
        System.out.println(user);
        r.db(config.getDatabase()).table("users").insert(user).run(connection);
    }
}
