package de.w665.sharepulse.rest.mappings;

import com.fasterxml.jackson.core.JsonProcessingException;
import de.w665.sharepulse.SharepulseApplication;
import de.w665.sharepulse.db.repo.UserLoginRepository;
import de.w665.sharepulse.db.repo.UserRepository;
import de.w665.sharepulse.model.FileUpload;
import de.w665.sharepulse.model.User;
import de.w665.sharepulse.rest.SecureApiRestController;
import de.w665.sharepulse.rest.ro.UserEditRequest;
import de.w665.sharepulse.service.AuthenticationService;
import de.w665.sharepulse.service.FileCleanupService;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@Slf4j
@RestController
public class Administration extends SecureApiRestController {

    private final UserRepository userRepository;
    private final AuthenticationService authenticationService;
    private final FileCleanupService fileCleanupService;
    private final UserLoginRepository userLoginRepository;

    public Administration(UserRepository userRepository, AuthenticationService authenticationService, FileCleanupService fileCleanupService, UserLoginRepository userLoginRepository) {
        this.userRepository = userRepository;
        this.authenticationService = authenticationService;
        this.fileCleanupService = fileCleanupService;
        this.userLoginRepository = userLoginRepository;
    }

    @GetMapping("/statistics")
    public ResponseEntity<Object> getStatistics(HttpServletRequest request) {

        // TODO: FIX LAST LOGIN

        String token = request.getHeader("Authorization");
        token = token.substring(7);
        String username = authenticationService.getClaimValue(token, "username", String.class);
        Optional<User> optionalUser = userRepository.retrieveUserByUsername(username);
        if(optionalUser.isEmpty()) {
            return ResponseEntity.badRequest().body("User not found");
        }
        User user = optionalUser.get();

        // If role filtering is required later, add here

        Map<String, Object> response = new HashMap<>();
        response.put("applicationOnlineTime", System.currentTimeMillis() - SharepulseApplication.startTime.getTime());
        try {
            response.put("lastUserLogin", userLoginRepository.getRecentUserLoginsForUser(user.getId(), 2));
        } catch (JsonProcessingException e) {
            response.put("lastUserLogin", "Error retrieving last user login");
        }
        log.debug("Received statistics request");
        return ResponseEntity.ok(response);
    }

    @PostMapping("/users")
    public ResponseEntity<Object> updateUser(@RequestBody UserEditRequest userEditRequest, HttpServletRequest request) {
        Optional<User> optionalUser = userRepository.retrieveUserByUsername(userEditRequest.getOriginalUsername());
        if(optionalUser.isEmpty()) {
            return ResponseEntity.badRequest().body("User not found");
        } else if (!userEditRequest.getNewPassword().equals(userEditRequest.getNewPasswordConfirm())) {
            return ResponseEntity.badRequest().body("Passwords do not match");
        } else if(userEditRequest.getNewPassword().length() < 4) {
            return ResponseEntity.badRequest().body("Password too short. Must be at least 4 characters.");
        }
        User user = optionalUser.get();
        user.setPassword(authenticationService.encodePassword(userEditRequest.getNewPassword()));
        user.setUsername(userEditRequest.getUsername());
        userRepository.updateUser(user, userEditRequest.getOriginalUsername());
        // Clear password before returning
        user.setPassword(null);
        return ResponseEntity.ok(user);
    }

    @DeleteMapping("/files")
    public ResponseEntity<Object> deleteFiles(HttpServletRequest request) {
        List<FileUpload> files = fileCleanupService.deleteFiles();
        return ResponseEntity.ok(files);
    }
}
