package de.w665.sharepulse.rest.mappings;

import de.w665.sharepulse.rest.ApiRestController;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;

@Slf4j
@RestController
public class SpeedTest extends ApiRestController {

    /**
     * This method is used to test the download speed of the client. 1MB of dummy data is sent to the client.
     * @param response
     */
    @GetMapping("/speed-test")
    public void speedTest(HttpServletResponse response) {
        byte[] dummyData = new byte[1024 * 1024 / 2];
        response.setContentType("application/octet-stream");
        response.setContentLength(dummyData.length);
        response.setStatus(HttpServletResponse.SC_OK);
        try {
            response.getOutputStream().write(dummyData);
            response.getOutputStream().flush();
        } catch (IOException e) {
            log.error("Speed test failed.");
            return;
        }
    }

    @PostMapping("/upload-speed-test")
    public void uploadSpeedTest(HttpServletRequest request, HttpServletResponse response) {
        final int maxBytes = 1024 * 1024 / 2; // Limit to 0.5MB
        byte[] buffer = new byte[1024]; // Buffer to read data
        int bytesRead;
        int totalBytesRead = 0;

        try (InputStream inputStream = request.getInputStream()) {
            while ((bytesRead = inputStream.read(buffer)) != -1 && totalBytesRead < maxBytes) {
                totalBytesRead += bytesRead;
            }
            response.setStatus(HttpServletResponse.SC_OK);
        } catch (IOException e) {
            log.error("Upload speed test failed.", e);
            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
        }
    }

}
