package de.w665.sharepulse.rest.mappings;

import com.google.gson.JsonObject;
import de.w665.sharepulse.model.FileUpload;
import de.w665.sharepulse.rest.ApiRestController;
import de.w665.sharepulse.service.FileService;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.Map;

@Slf4j
@RestController
public class Upload extends ApiRestController {

    private final FileService fileService;

    @Autowired
    public Upload(FileService fileService) {
        this.fileService = fileService;
    }

    // Currently testing
    @PostMapping("/upload")
    public ResponseEntity<Map<String, Object>> getUpload(@RequestParam("file") MultipartFile file, HttpServletRequest request,
                                            @RequestParam(value = "passwordProtected", required = false) Boolean passwordProtected,
                                            @RequestParam(value = "singleDownload", defaultValue = "false") boolean singleDownload,
                                            @RequestParam(value = "fileDescription", required = false) String fileDescription) {

        // TODO: Handle shortStorage

        if (file.isEmpty()) {
            log.debug("User tried to upload an empty file. IP: " + request.getRemoteAddr());
            Map<String, Object> response = new HashMap<>();
            response.put("message", "Please select a file to upload.");
            return new ResponseEntity<>(response, HttpStatus.NOT_ACCEPTABLE);
        }

        FileUpload fileUpload = fileService.processUploadedFile(file, request.getRemoteAddr(), passwordProtected, singleDownload, fileDescription);

        if(fileUpload == null) {
            log.debug("File Upload failed for IP: " + request.getRemoteAddr());
            Map<String, Object> response = new HashMap<>();
            response.put("message", "FileUpload failed. FileName might have invalid characters.");
            return new ResponseEntity<>(response, HttpStatus.BAD_REQUEST);
        }

        log.info("User uploaded file \"" + file.getOriginalFilename() + "\" from IP " + request.getRemoteAddr() + " successfully.");

        Map<String, Object> response = new HashMap<>();
        response.put("fileId", fileUpload.getFileId());
        response.put("fileName", fileUpload.getFileName());
        response.put("message", "File " + fileUpload.getFileName() + " uploaded successfully!");
        response.put("passwordProtected", fileUpload.isPasswordProtected());
        response.put("singleDownload", fileUpload.isSingleDownload());
        response.put("uploadDate", fileUpload.getUploadDate().toString());
        response.put("password", fileUpload.getDownloadPassword());

        return new ResponseEntity<>(response, HttpStatus.OK);
    }
}
