package de.w665.sharepulse.service;

import de.w665.sharepulse.db.repo.FileIdRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.security.SecureRandom;
import java.text.SimpleDateFormat;
import java.util.Date;

@Service
public class FileIdService {

    @Value("${sharepulse.fileid.length}")
    private int fileIdLength;

    @Value("${sharepulse.fileid.charset}")
    private String CHARSET;

    private final FileIdRepository fileIdRepository;
    private static final SecureRandom RANDOM = new SecureRandom();

    @Autowired
    public FileIdService(FileIdRepository fileIdRepository) {
        this.fileIdRepository = fileIdRepository;
    }

    private String generateId() {
        String uniqueId;
        do {
            uniqueId = generateRandomCode(fileIdLength);
        } while (fileIdRepository.fileIdExists(uniqueId));
        fileIdRepository.insertFileId(uniqueId);
        return uniqueId;
    }

    private String generateRandomCode(int length) {
        StringBuilder sb = new StringBuilder(length);
        for (int i = 0; i < length; i++) {
            int index = RANDOM.nextInt(CHARSET.length());
            sb.append(CHARSET.charAt(index));
        }
        return sb.toString();
    }

    public String generateNewUniqueId() {
        return generateId();
    }

}
