package de.w665.sharepulse.service;

import de.w665.sharepulse.exception.NoDownloadPermissionException;
import de.w665.sharepulse.model.FileUpload;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.security.SecureRandom;
import java.util.Random;

@Slf4j
@Service
public class FileSecurityService {

    @Value("${sharepulse.filepassword.length}")
    private int passwordLength;
    @Value("${sharepulse.filepassword.charset}")
    private String passwordCharset;
    private final Random random = new SecureRandom();

    public boolean verifyDownloadPermission(FileUpload file, String password) throws NoDownloadPermissionException {

        if(file.isDisabled()) {
            throw new NoDownloadPermissionException("File download has been disabled.");
        }

        if (!file.isPasswordProtected() && !file.isSingleDownload()) {
            return true;
        }

        if (file.isSingleDownload()) {
            if(file.getDownloadCount() > 0) {
                throw new NoDownloadPermissionException("File has already been downloaded.");
            }
            if(!file.isPasswordProtected()) {
                return true;
            }
        }

        if(file.getDownloadPassword().equals(password)) {
            return true;
        }

        throw new NoDownloadPermissionException("Password protected file can only be downloaded with correct password.");

    }

    public String generateFilePassword() {
        StringBuilder password = new StringBuilder(passwordLength);

        for (int i = 0; i < passwordLength; i++) {
            int randomIndex = random.nextInt(passwordCharset.length());
            char randomChar = passwordCharset.charAt(randomIndex);
            password.append(randomChar);
        }

        return password.toString();
    }
}
